//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[tiles](tiles.md)

# tiles

[common]\
val [tiles](tiles.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;? = null

#### Parameters

common

| | |
|---|---|
| tiles | 门前的牌 |
